# Examples

A gallery of examples to showcase how iohub can be used.

## OME-Zarr Writing

- [Single-FOV OME-Zarr](single_fov_ome_zarr.md) - Create, read, append, and modify a single-FOV dataset
- [Multi-FOV HCS OME-Zarr](multi_fov_hcs_ome_zarr.md) - Write a high content screening dataset with multiple wells
- [Large Array OME-Zarr](large_array_ome_zarr.md) - Store larger-than-RAM arrays
- [Tiled OME-Zarr](tiled_ome_zarr.md) - Create a tiled single-resolution dataset
- [Update OME-Zarr](update_ome_zarr.md) - Convert between OME-Zarr versions

## Transforms and Pyramids

- [Coordinate Transform](coordinate_transform.md) - Write FOVs with different coordinate transformations
- [Create Pyramid](create_pyramid.md) - Create a multiscale pyramid for visualization

## Legacy Formats

- [View ClearControl Dataset](view_clearcontrol_dataset.md) - Open and view a ClearControl dataset
